Clazz.declarePackage("JSV.api.js");
Clazz.declareInterface(JSV.api.js, "JSVToJSmolInterface", javajs.api.js.J2SObjectInterface);
;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
